#ifndef __ALSA_RECIPE_H
#define __ALSA_RECIPE_H

/* Build with TLV support */
#define SALSA_HAS_TLV_SUPPORT	1

/* Build with async support */
#define SALSA_HAS_ASYNC_SUPPORT	1

#endif /* __ALSA_RECIPE_H */
